package org.informatika.ojek;

import com.google.gson.Gson;
import org.informatika.ojek.model.Account;
import org.informatika.ojek.model.AccountDAO;
import org.informatika.ojek.model.Response;

import java.io.IOException;
import java.io.PrintWriter;
import java.sql.SQLException;
import javax.servlet.ServletException;
import javax.servlet.annotation.WebServlet;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import static jdk.nashorn.internal.runtime.regexp.joni.Config.log;

/**
 *
 * @author fadhilimamk
 */
@WebServlet(name = "Auth", urlPatterns = {"/auth"})
public class Auth extends HttpServlet {

    private AccountDAO accountDAO;
    private Gson gson;

    public void init() {
        String jdbcURL = getServletContext().getInitParameter("jdbcURL");
        String jdbcUsername = getServletContext().getInitParameter("jdbcUsername");
        String jdbcPassword = getServletContext().getInitParameter("jdbcPassword");

        accountDAO = new AccountDAO(jdbcURL, jdbcUsername, jdbcPassword);
        gson = new Gson();
    }

    @Override
    protected void doPost(HttpServletRequest request, HttpServletResponse response)
            throws ServletException, IOException {
        response.setContentType("text/html;charset=UTF-8");
        response.setStatus(200);
        
        PrintWriter out = response.getWriter();
        
        String username = request.getParameter("username");
        String password = request.getParameter("password");

        Response data;
        String dataResponse;

        // Check username and password in post body
        if (username == null || password == null) {
            response.setStatus(500);
            data = new Response(Response.STATUS_ERROR, null,  null, "Wrong parameter!");

            dataResponse = gson.toJson(data);
            out.print(dataResponse);
            return;
        }

        int userId = -1;
        userId = accountDAO.checkAvailability(username, password);

        // Check if user exist
        if (userId == -1) {
            response.setStatus(500);
            data = new Response(Response.STATUS_ERROR, null, null, "Wrong username or password!");

            dataResponse = gson.toJson(data);
            out.print(dataResponse);
        }

        String token = null;

        // Check if already login

        // Generate token
        try {
            token = Account.generateToken(userId, username, password);
            accountDAO.saveToken(userId, token);
        } catch (Exception e) {
            data = new Response(Response.STATUS_ERROR, null, null, e.getMessage());
            dataResponse = gson.toJson(data);
            out.print(dataResponse);
            return;
        }
        
        data = new Response(Response.STATUS_SUCCESS, token, null, null);

        dataResponse = gson.toJson(data);
        out.print(dataResponse);

    }

}
