/*
 * To change this license header, choose License Headers in Project Properties.
 * To change this template file, choose Tools | Templates
 * and open the template in the editor.
 */
package org.informatika.ojek.model;

import java.sql.*;
import java.util.ArrayList;
import java.util.List;

import static jdk.nashorn.internal.runtime.regexp.joni.Config.log;

/**
 *
 * @author fadhilimamk
 */
public class AccountDAO {
    private String jdbcURL;
    private String jdbcUsername;
    private String jdbcPassword;
    private Connection jdbcConnection;

    public AccountDAO(String jdbcURL, String jdbcUsername, String jdbcPassword) {
        this.jdbcURL = jdbcURL;
        this.jdbcUsername = jdbcUsername;
        this.jdbcPassword = jdbcPassword;
    }
   
    private void connect() throws SQLException {
        if (jdbcConnection == null || jdbcConnection.isClosed()) {
            try {
                Class.forName("com.mysql.jdbc.Driver");
            } catch (ClassNotFoundException e) {
                throw new SQLException(e);
            }
            jdbcConnection = DriverManager.getConnection(
                                        jdbcURL, jdbcUsername, jdbcPassword);
        }
    }
    
    private void disconnect() throws SQLException {
        if (jdbcConnection != null && !jdbcConnection.isClosed()) {
            jdbcConnection.close();
        }
    }
     
    public List<Account> listAllAccount() throws SQLException {
        List<Account> listAccount = new ArrayList<>();
         
        String sql = "SELECT * FROM account";
         
        connect();
         
        Statement statement = jdbcConnection.createStatement();
        ResultSet resultSet = statement.executeQuery(sql);
         
        while (resultSet.next()) {
            int id = resultSet.getInt("id");
            String name = resultSet.getString("name");
            String username = resultSet.getString("username");
            String email = resultSet.getString("email");
            String phone = resultSet.getString("phone");
            String photo = resultSet.getString("photo");
            Boolean isDriver = resultSet.getBoolean("is_driver");
             
            Account account = new Account(id, name, username, email, phone, photo, isDriver);
            listAccount.add(account);
        }
         
        resultSet.close();
        statement.close();
         
        disconnect();
         
        return listAccount;
    }

    public int checkAvailability(String username, String password) {
        String sql = "SELECT id FROM account WHERE username = ? AND password = MD5(?)";

        try {
            connect();

            PreparedStatement statement = jdbcConnection.prepareStatement(sql);
            statement.setString(1, username);
            statement.setString(2, password);
            ResultSet resultSet = statement.executeQuery();

            if (resultSet.next()) {
                int id = resultSet.getInt("id");
                resultSet.close();
                statement.close();

                disconnect();
                return id;
            }

            resultSet.close();
            statement.close();

            disconnect();
        } catch (SQLException e) {
            e.printStackTrace();
        }

        return -1;
    }

    public void saveToken(int idUser, String token) throws SQLException{
        String sql = "INSERT INTO token (token, expire_at, id_account) VALUES (?, ?, ?)";

        // 5 minute expire
        Timestamp expire = new Timestamp(System.currentTimeMillis()+5*60*1000);

        connect();
        PreparedStatement statement = jdbcConnection.prepareStatement(sql);
        statement.setString(1, token);
        statement.setTimestamp(2, expire);
        statement.setInt(3, idUser);

        int rowCount = statement.executeUpdate();

        disconnect();
    }

    public void logoutUser(int idUser) throws SQLException{
        String sql = "DELETE FROM token WHERE id_account = ?";

        connect();
        PreparedStatement statement = jdbcConnection.prepareStatement(sql);
        statement.setInt(1, idUser);

        disconnect();
    }
    
}
